import ArweaveProxy from "./proxies/arweave-proxy";
import { PriceData, GetPriceOptions, LimestoneApiConfig, GetHistoricalPriceOptions, GetHistoricalPriceForIntervalOptions } from "./types";
export default class LimestoneApi {
    private defaultProvider;
    private useCache;
    private version;
    private verifySignature;
    private arweaveProxy;
    private cacheProxy;
    constructor(opts: {
        defaultProvider?: string;
        useCache?: boolean;
        version?: string;
        verifySignature?: boolean;
        arweaveProxy: ArweaveProxy;
    });
    static init(limestoneConfig?: LimestoneApiConfig): LimestoneApi;
    getPrice(symbol: string, opts?: GetPriceOptions): Promise<PriceData>;
    getPrice(symbols: string[], opts?: GetPriceOptions): Promise<{
        [token: string]: PriceData;
    }>;
    /**
     * Returns the historical price for a single token
     *
     * @remarks
     * Full list of supported tokens is available at
     * {@link https://github.com/limestone-finance/limestone-api/blob/main/ALL_SUPPORTED_TOKENS.md}
     *
     * @param symbol - Token symbol
     * @param opts - Options object. It must contain the date property.
     * * date: Date for the historical price
     * @returns The historical price for token
     *
     */
    getHistoricalPrice(symbol: string, opts: GetHistoricalPriceOptions): Promise<PriceData>;
    /**
     * Returns the historical prices for a token in a time range with the specified interval
     *
     * @remarks
     * This method can be used to display charts with historical prices.
     * Full list of supported tokens is available at
     * {@link https://github.com/limestone-finance/limestone-api/blob/main/ALL_SUPPORTED_TOKENS.md}
     *
     * @param symbol - Token symbol
     * @param opts - Options object. It must contain startDate, endDate, and interval properties.
     * * startDate: Start time for the time range (date | timestamp | string)
     * * endDate: End time for the time range (date | timestamp | string)
     * * interval: Interval in miliseconds (number)
     * @returns The historical prices for the symbol with the passed interval
     *
     */
    getHistoricalPrice(symbol: string, opts: GetHistoricalPriceForIntervalOptions): Promise<PriceData[]>;
    /**
     * Returns the historical prices for several tokens
     *
     * @param symbols - Array of token symbols
     * @param opts - Options object. It must contain the date property.
     * * date: Date for the historical price (date | timestamp | string)
     * @returns The historical prices for several tokens
     *
     */
    getHistoricalPrice(symbols: string[], opts: GetHistoricalPriceOptions): Promise<{
        [token: string]: PriceData;
    }>;
    getAllPrices(opts?: GetPriceOptions): Promise<{
        [symbol: string]: PriceData;
    }>;
    private getLatestPriceForOneToken;
    private getPriceForManyTokens;
    private getPricesFromArweave;
    private getHistoricalPriceForOneSymbol;
    private tryToGetPriceFromGQL;
    private getHistoricalPricesInIntervalForOneSymbol;
    private assertValidSignature;
    private getPriceSignedData;
}
